//go:build wireinject
// +build wireinject

package cmd

import (
	"leafdev.top/Leaf/api-platform/internal/base"
	"leafdev.top/Leaf/api-platform/internal/base/conf"
	"leafdev.top/Leaf/api-platform/internal/base/logger"
	"leafdev.top/Leaf/api-platform/internal/base/orm"
	"leafdev.top/Leaf/api-platform/internal/base/redis"
	"leafdev.top/Leaf/api-platform/internal/base/s3"
	"leafdev.top/Leaf/api-platform/internal/base/server"
	"leafdev.top/Leaf/api-platform/internal/batch"
	"leafdev.top/Leaf/api-platform/internal/dao"
	"leafdev.top/Leaf/api-platform/internal/handler"
	"leafdev.top/Leaf/api-platform/internal/router"
	"leafdev.top/Leaf/api-platform/internal/service"

	"github.com/google/wire"
)

var ProviderSet = wire.NewSet(
	conf.ProviderConfig,
	logger.NewZapLogger,
	orm.NewGORM,
	dao.NewQuery,
	redis.NewRedis,
	s3.NewS3,
	batch.NewBatch,
	service.Provider,
	handler.ProviderSet,
	router.ProviderSetRouter,
	server.NewHTTPServer,
	base.NewApplication,
)

func CreateApp() (*base.Application, error) {
	wire.Build(ProviderSet)

	return nil, nil
}
